import { Config } from './config.js';

export class Camera {
	private static readonly MOVE_MODIFIER = 10;
	private screen?: HTMLElement;
	private top = 0;
	private left = 0;

	constructor() {
		this.reset();
	}

	public get axis() {
		return { x: this.left, y: this.top };
	}

	public reset() {
		this.xAxis = 0;
		this.yAxis = 0;
	}

	public setScreen(screen: HTMLElement) {
		this.screen = screen;
	}

	public moveUp() {
		this.yAxis = this.top + Config.StepCount;
	}

	public moveDown() {
		this.yAxis = this.top - Config.StepCount;
	}

	public moveLeft() {
		if (this.left < 0 && this.left < (Config.StepCount * Config.PlayerAcceleration)) {
			this.xAxis = this.left + Config.StepCount;
		}
	}

	public moveRight() {
		this.xAxis = this.left - Config.StepCount;
	}

	private set yAxis(val: number) {
		this.top = val;
		if (this.screen != null) {
			this.screen.style.top = `${val * Camera.MOVE_MODIFIER}px`;
		}
	}

	private set xAxis(val: number) {
		this.left = val;
		if (this.screen != null) {
			this.screen.style.left = `${val * Camera.MOVE_MODIFIER}px`;
		}
	}
}
