export class Inspectable extends HTMLElement {

	private view = document.createElement('article');
	private header = document.createElement('header');
	private body = document.createElement('section');

	constructor() {
		super();

		this.style.display = 'block';
		this.style.position = 'relative';
		this.style.height = '100%';
		this.style.width = '100%';

		this.view.appendChild(this.header);
		this.view.appendChild(this.body);
		this.view.classList.add('view');
	}

	public get dimensions() {
		const { left, top, height, width } = this.getBoundingClientRect();
		return { left, top, height, width };
	}

	public setIcon(name: string) {
		this.style.background = `url('images/${name}.png')`;
		this.style.backgroundRepeat = 'no-repeat';
		this.style.backgroundSize = 'contain';
		return this;
	}
	public setView(view: { header?: string, body?: string }) {
		this.header.innerText = view.header ?? '';
		this.body.innerText = view.body ?? '';
		return this;
	}

	public open() {
		const { parentElement } = this;
		if (parentElement == null) return;

		parentElement.appendChild(this.view);
		parentElement.onclick = () => {
			parentElement.removeChild(this.view);
			parentElement.onclick = null;
		};
	}

	public close() {
		const { parentElement } = this;
		if (parentElement == null) return;

		if (typeof parentElement.onclick === 'function') {
			parentElement.click();
		}
	}
}
