import { Door, Game, Inspectable, Inventory, Room, bootstrap } from '../lib/index.js';
import { lrObjects } from './living-room.js';

bootstrap();

const game = new Game();
const livingRoom = new Room({ rows: 16, columns: 16, name: 'Living Room' });
const tvRoom = new Room({ rows: 12, columns: 12, name: 'TV Room' });
const exit = new Room({ rows: 12, columns: 12, name: 'Exit' });

livingRoom.addObject(8, 1, new Door(tvRoom).setIcon('tv'));
livingRoom.addObject(8, 16, new Door(exit)
	.setIcon('locked')
	.setView({ header: 'The Door Is Locked', body: 'You need a key to enter' })
	.onOpen(e => {
		if (Inventory.hasItem('key')) {
			return;
		}
		e.preventDefault();
		Inventory.addItem('key');
	}),
);

tvRoom.addObject(1, 1, new Door(livingRoom)
	.setIcon('locked')
	.setView({ header: 'Enter Keycode', body: '0481' })
	.onOpen(e => {
		if (Inventory.hasItem('keycode-passed')) {
			return;
		}
		e.preventDefault();
		Inventory.addItem('keycode-passed');
	}),
);

for (const { row, column, icon, view } of lrObjects) {
	tvRoom.addObject(row, column, new Inspectable().setIcon(icon).setView(view));
}

game.addRoom(livingRoom);
game.addRoom(tvRoom);
game.addRoom(exit);

livingRoom.open();

document.body.appendChild(game);

// const input = document.createElement('input');
// livingRoom.addHeaderNode(input);

// input.type = 'range';
// input.max = '100';
// input.min = '1';
// input.style.zIndex = '4';
// input.style.backgroundColor = 'white';

// input.addEventListener('change', e => {
// 	const v = Number((e.target as any).value);
// 	requestAnimationFrame(() => livingRoom.resize(v));
// });
